Learn R Programming

cyjShiny (version 1.0.42)

fit: Set zoom and center of the graph display so that graph fills the display.

Description

Set zoom and center of the graph display so that graph fills the display.

Usage

fit(session, padding = 50)

Value

Nothing

Arguments

session

a Shiny server session object.

padding

integer, default 50 pixels.

See Also

fitSelected

Examples

Run this code
if (FALSE) {
fit(session, 100)
}

Run the code above in your browser using DataLab