Learn R Programming

cyjShiny (version 1.0.42)

fitSelected: Set zoom and center of the graph display so that the currently selected nodes fill the display

Description

Set zoom and center of the graph display so that the currently selected nodes fill the display

Usage

fitSelected(session, padding = 50)

Value

Nothing

Arguments

session

a Shiny server session object.

padding

integer, default 50 pixels.

See Also

fit

Examples

Run this code
if (FALSE) {
fitSelected(session, 100)
}

Run the code above in your browser using DataLab