powered by
Set zoom and center of the graph display so that the currently selected nodes fill the display
fitSelected(session, padding = 50)
Nothing
a Shiny server session object.
integer, default 50 pixels.
fit
if (FALSE) { fitSelected(session, 100) }
Run the code above in your browser using DataLab